==> degov-8.x-5.30.tar.gz: degov/testing/behat/context/DrupalIndependentContext.php <==
<?php

namespace Drupal\degov\Behat\Context;

use Behat\Mink\Element\NodeElement;
use Behat\Mink\Exception\ResponseTextException;
use Behat\MinkExtension\Context\RawMinkContext;
use Behat\Testwork\Hook\HookDispatcher;
use Drupal\degov\Behat\Context\Traits\TranslationTrait;
use WebDriver\Exception\StaleElementReference;


class DrupalIndependentContext extends RawMinkContext {

	use TranslationTrait;

	private const MAX_DURATION_SECONDS = 1200;
	private const MAX_SHORT_DURATION_SECONDS = 10;

	/**
	 * {@inheritdoc}
	 */
	public function setDispatcher(HookDispatcher $dispatcher) {
		$this->dispatcher = $dispatcher;
	}

	/**
	 * @param $name
	 *
	 * @return string
	 * @throws \Exception
	 */
	public function getDrupalSelector($name) {
		$text = $this->getDrupalParameter('selectors');
		if (!isset($text[$name])) {
			throw new \Exception(sprintf('No such selector configured: %s', $name));
		}
		return $text[$name];
	}

	/**
	 * Get driver's random generator.
	 */
	public function getRandom() {
		return $this->getDriver()->getRandom();
	}

	/**
	 * @Then /^I should see "([^"]*)" exactly "([^"]*)" times$/
	 */
	public function iShouldSeeTextSoManyTimes($sText, $iExpected)
	{
		$sContent = $this->getSession()->getPage()->getText();
		$iFound = substr_count($sContent, $sText);
		if ($iExpected != $iFound) {
			throw new \Exception('Found '.$iFound.' occurences of "'.$sText.'" when expecting '.$iExpected);
		}
	}

	/**
	 * @Then /^I should see text matching "([^"]*)" via translated text in uppercase after a while$/
	 */
	public function iShouldSeeTranslatedUppercaseTextAfterAWhile(string $text): bool
	{
		$translatedText = mb_strtoupper($this->translateString($text));

		try {
			$startTime = time();
			do {
				$content = $this->getSession()->getPage()->getText();
				if (substr_count($content, $translatedText) > 0) {
					return true;
				}
			} while (time() - $startTime < self::MAX_DURATION_SECONDS);
			throw new ResponseTextException(
				sprintf('Could not find text %s after %s seconds', $translatedText, self::MAX_DURATION_SECONDS),
				$this->getSession()
			);
		} catch (StaleElementReference $e) {
			return true;
		}
	}

	/**
	 * @Then /^I should see text matching "([^"]*)" via translated text after a while$/
	 */
	public function iShouldSeeTranslatedTextAfterAWhile(string $text): bool
	{
		$translatedText = $this->translateString($text);

		try {
			$startTime = time();
			do {
				$content = $this->getSession()->getPage()->getText();
				if (substr_count($content, $translatedText) > 0) {
					return true;
				}
			} while (time() - $startTime < self::MAX_DURATION_SECONDS);
			throw new ResponseTextException(
				sprintf('Could not find text %s after %s seconds', $translatedText, self::MAX_DURATION_SECONDS),
				$this->getSession()
			);
		} catch (StaleElementReference $e) {
			return true;
		}
	}

	/**
	 * @Then /^I should see text matching "([^"]*)" after a while$/
	 */
	public function iShouldSeeTextAfterAWhile(string $text): bool
	{
		try {
			$startTime = time();
			do {
				$content = $this->getSession()->getPage()->getText();
				if (substr_count($content, $text) > 0) {
					return true;
				}
			} while (time() - $startTime < self::MAX_DURATION_SECONDS);
			throw new ResponseTextException(
				sprintf('Could not find text %s after %s seconds', $text, self::MAX_DURATION_SECONDS),
				$this->getSession()
			);
		} catch (StaleElementReference $e) {
			return true;
		}
	}

  /**
   * @Then /^I should see HTML content matching "([^"]*)"$/
   */
  public function iShouldSeeHTMLContentMatching(string $content)
  {
    $html = $this->getSession()->getPage()->getHtml();
    if (substr_count($html, $content) > 0) {
      return true;
    }

    throw new ResponseTextException(
      sprintf('HTML does not contain content "%s"', $content),
      $this->getSession());
  }

  /**
   * @Then /^I should not see HTML content matching "([^"]*)"$/
   */
  public function iShouldNotSeeHTMLContent($html)
  {
    $content = $this->getSession()->getPage()->getText();
    if (substr_count($content, $html) === 0) {
      return true;
    }
  }

  /**
   * @Then /^I should see HTML content matching "([^"]*)" after a while$/
   */
  public function iShouldSeeHTMLContentMatchingAfterWhile($text)
  {
    try {
      $startTime = time();
      do {
        $content = $this->getSession()->getPage()->getHtml();
        if (substr_count($content, $text) > 0) {
          return true;
        }
      } while (time() - $startTime < self::MAX_DURATION_SECONDS);
      throw new ResponseTextException(
        sprintf('Could not find text %s after %s seconds', $text, self::MAX_DURATION_SECONDS),
        $this->getSession()
      );
    } catch (StaleElementReference $e) {
      return true;
    }
  }

	/**
	 * @Then /^I should not see text matching "([^"]*)" after a while$/
	 */
	public function iShouldNotSeeTextAfterAWhile($text)
	{
		$startTime = time();
		do {
			$content = $this->getSession()->getPage()->getText();
			if (substr_count($content, $text) === 0) {
				return true;
			}
		} while (time() - $startTime < self::MAX_SHORT_DURATION_SECONDS);
		throw new ResponseTextException(
			sprintf('Could find text %s after %s seconds', $text, self::MAX_SHORT_DURATION_SECONDS),
			$this->getSession()
		);
	}

  /**
   * @Then /^wait (\d+) seconds$/
   */
  public function waitSeconds($secondsNumber) {
    $this->getSession()->wait($secondsNumber * 1000);
  }

  /**
   * @Then /^I proof xpath "([^"]*)" contains text$/
   */
  public function xpathContainsText(string $xpath) {
    $page = $this->getSession()->getPage();
    /** @var $xpathNode \Behat\Mink\Element\NodeElement */
    $xpathNode = $page->find('xpath', $xpath);

    if (empty(\trim(\strip_tags($xpathNode->getHtml())))) {
      throw new \Exception("Xpath $xpath does not contain any text.");

    }
  }

  /**
   * @Then /^I proof css "([^"]*)" contains text$/
   */
  public function cssContainsText(string $css) {
    $page = $this->getSession()->getPage();
    /** @var $node \Behat\Mink\Element\NodeElement */
    $node = $page->find('css', $css);

    if (empty(\trim(\strip_tags($node->getHtml())))) {
      throw new \Exception("CSS $css does not contain any text.");
    }
  }

  /**
   * @Then /^I proof css selector "([^"]*)" matches a DOM node$/
   */
  public function cssSelectorMatchesDOMNode(string $css) {
    $page = $this->getSession()->getPage();
    /** @var $cssSelector NodeElement */
    $cssSelector = $page->find('css', $css);

    if (!$cssSelector instanceof NodeElement) {
      throw new \Exception("CSS selector $css is not of expected object type NodeElement.");
    }
  }

}

==> degov-8.x-5.101.tar.gz: degov/testing/behat/context/DrupalIndependentContext.php <==
<?php

namespace Drupal\degov\Behat\Context;

use Behat\Mink\Element\NodeElement;
use Behat\Mink\Exception\ResponseTextException;
use Behat\MinkExtension\Context\RawMinkContext;
use Behat\Testwork\Hook\HookDispatcher;
use Drupal\degov\Behat\Context\Traits\TranslationTrait;
use WebDriver\Exception\StaleElementReference;


class DrupalIndependentContext extends RawMinkContext {

	use TranslationTrait;

	private const MAX_DURATION_SECONDS = 1200;
	private const MAX_SHORT_DURATION_SECONDS = 10;

	/**
	 * {@inheritdoc}
	 */
	public function setDispatcher(HookDispatcher $dispatcher) {
		$this->dispatcher = $dispatcher;
	}

	/**
	 * @param $name
	 *
	 * @return string
	 * @throws \Exception
	 */
	public function getDrupalSelector($name) {
		$text = $this->getDrupalParameter('selectors');
		if (!isset($text[$name])) {
			throw new \Exception(sprintf('No such selector configured: %s', $name));
		}
		return $text[$name];
	}

	/**
	 * Get driver's random generator.
	 */
	public function getRandom() {
		return $this->getDriver()->getRandom();
	}

	/**
	 * @Then /^I should see "([^"]*)" exactly "([^"]*)" times$/
	 */
	public function iShouldSeeTextSoManyTimes($sText, $iExpected)
	{
		$sContent = $this->getSession()->getPage()->getText();
		$iFound = substr_count($sContent, $sText);
		if ($iExpected != $iFound) {
			throw new \Exception('Found '.$iFound.' occurences of "'.$sText.'" when expecting '.$iExpected);
		}
	}

	/**
	 * @Then /^I should see text matching "([^"]*)" via translated text in uppercase after a while$/
	 */
	public function iShouldSeeTranslatedUppercaseTextAfterAWhile(string $text): bool
	{
		$translatedText = mb_strtoupper($this->translateString($text));

		try {
			$startTime = time();
			do {
				$content = $this->getSession()->getPage()->getText();
				if (substr_count($content, $translatedText) > 0) {
					return true;
				}
			} while (time() - $startTime < self::MAX_DURATION_SECONDS);
			throw new ResponseTextException(
				sprintf('Could not find text %s after %s seconds', $translatedText, self::MAX_DURATION_SECONDS),
				$this->getSession()
			);
		} catch (StaleElementReference $e) {
			return true;
		}
	}

	/**
	 * @Then /^I should see text matching "([^"]*)" via translated text after a while$/
	 */
	public function iShouldSeeTranslatedTextAfterAWhile(string $text): bool
	{
		$translatedText = $this->translateString($text);

		try {
			$startTime = time();
			do {
				$content = $this->getSession()->getPage()->getText();
				if (substr_count($content, $translatedText) > 0) {
					return true;
				}
			} while (time() - $startTime < self::MAX_DURATION_SECONDS);
			throw new ResponseTextException(
				sprintf('Could not find text %s after %s seconds', $translatedText, self::MAX_DURATION_SECONDS),
				$this->getSession()
			);
		} catch (StaleElementReference $e) {
			return true;
		}
	}

	/**
	 * @Then /^I should see text matching "([^"]*)" after a while$/
	 */
	public function iShouldSeeTextAfterAWhile(string $text): bool
	{
		try {
			$startTime = time();
			do {
				$content = $this->getSession()->getPage()->getText();
				if (substr_count($content, $text) > 0) {
					return true;
				}
			} while (time() - $startTime < self::MAX_DURATION_SECONDS);
			throw new ResponseTextException(
				sprintf('Could not find text %s after %s seconds', $text, self::MAX_DURATION_SECONDS),
				$this->getSession()
			);
		} catch (StaleElementReference $e) {
			return true;
		}
	}

  /**
   * @Then /^I should see HTML content matching "([^"]*)"$/
   */
  public function iShouldSeeHTMLContentMatching(string $content)
  {
    $html = $this->getSession()->getPage()->getHtml();
    if (substr_count($html, $content) > 0) {
      return true;
    }

    throw new ResponseTextException(
      sprintf('HTML does not contain content "%s"', $content),
      $this->getSession());
  }

  /**
   * @Then /^I should not see HTML content matching "([^"]*)"$/
   * @Then /^I should not see HTML content matching '([^']*)'$/
   */
  public function iShouldNotSeeHTMLContentMatching(string $content): ?bool
  {
    $html = $this->getSession()->getPage()->getHtml();
    if (substr_count($html, $content) === 0) {
      return true;
    }

    throw new ResponseTextException(
      sprintf('HTML does contain content "%s"', $content),
      $this->getSession());
  }

  /**
   * @Then /^I should see HTML content matching "([^"]*)" after a while$/
   */
  public function iShouldSeeHTMLContentMatchingAfterWhile($text)
  {
    try {
      $startTime = time();
      do {
        $content = $this->getSession()->getPage()->getHtml();
        if (substr_count($content, $text) > 0) {
          return true;
        }
      } while (time() - $startTime < self::MAX_DURATION_SECONDS);
      throw new ResponseTextException(
        sprintf('Could not find text %s after %s seconds', $text, self::MAX_DURATION_SECONDS),
        $this->getSession()
      );
    } catch (StaleElementReference $e) {
      return true;
    }
  }

	/**
	 * @Then /^I should not see text matching "([^"]*)" after a while$/
	 */
	public function iShouldNotSeeTextAfterAWhile($text)
	{
		$startTime = time();
		do {
			$content = $this->getSession()->getPage()->getText();
			if (substr_count($content, $text) === 0) {
				return true;
			}
		} while (time() - $startTime < self::MAX_SHORT_DURATION_SECONDS);
		throw new ResponseTextException(
			sprintf('Could find text %s after %s seconds', $text, self::MAX_SHORT_DURATION_SECONDS),
			$this->getSession()
		);
	}

  /**
   * @Then /^wait (\d+) seconds$/
   */
  public function waitSeconds($secondsNumber) {
    $this->getSession()->wait($secondsNumber * 1000);
  }

  /**
   * @Then /^I proof xpath "([^"]*)" contains text$/
   */
  public function xpathContainsText(string $xpath) {
    $page = $this->getSession()->getPage();
    /** @var $xpathNode \Behat\Mink\Element\NodeElement */
    $xpathNode = $page->find('xpath', $xpath);

    if (empty(\trim(\strip_tags($xpathNode->getHtml())))) {
      throw new \Exception("Xpath $xpath does not contain any text.");

    }
  }

  /**
   * @Then /^I proof css "([^"]*)" contains text$/
   */
  public function cssContainsText(string $css) {
    $page = $this->getSession()->getPage();
    /** @var $node \Behat\Mink\Element\NodeElement */
    $node = $page->find('css', $css);

    if (empty(\trim(\strip_tags($node->getHtml())))) {
      throw new \Exception("CSS $css does not contain any text.");
    }
  }

  /**
   * @Then /^I proof css selector "([^"]*)" matches a DOM node$/
   */
  public function cssSelectorMatchesDOMNode(string $css) {
    $page = $this->getSession()->getPage();
    /** @var $cssSelector NodeElement */
    $cssSelector = $page->find('css', $css);

    if (!$cssSelector instanceof NodeElement) {
      throw new \Exception("CSS selector $css is not of expected object type NodeElement.");
    }
  }

}
